@@ -115,7 +115,7 @@ gpa_utils_dump_tree_with_level (GPANode *node, gint level, gint follow_reference
 	}
 
 	if (strcmp (G_OBJECT_TYPE_NAME (node), "GPAKey") == 0)
-		g_print (" {%s}", ((GPAKey *) node)->value);
+		g_print (" {%s}", ((GPAKey *) node)->value ? ((GPAKey *) node)->value : "");
 	if (strcmp (G_OBJECT_TYPE_NAME (node), "GPAState") == 0)
 		g_print (" state: [%s]", ((GPAState *) node)->value);
 	if (strcmp (G_OBJECT_TYPE_NAME (node), "GPAOption") == 0) {
