@@ -307,7 +307,7 @@ option_list_new_with_default (GPANode      *parent,
 }
 
 static GPANode *
-load_paper_sizes (ppd_file_t const *ppd, GPANode *parent)
+load_paper_sizes (ppd_file_t *ppd, GPANode *parent)
 {
 	ppd_option_t *option;
 	GPANode *node;
@@ -615,9 +615,9 @@ cb_get_ppd (guint id, ppd_file_t *ppd, GError **error, gpointer user_data)
 						     GPA_SETTINGS (settings));
 
 		if (success) {
-			gpa_list_prepend (printers_list, printer);
 			if (gnome_cups_printer_get_is_default (cupsprinter))
 				gpa_list_set_default (printers_list, printer);
+			gpa_list_prepend (printers_list, printer);
 		}
 	} else {
 		g_warning ("The CUPS printer %s could not be created\n", name);
